pub enum Flags {
LeLimited,
LeDiscoverable,
NoBrEdr,
BrEdrController,
BrEdrHost,
}Expand description
Features in the Flags AD
Variants
Implementations
Sourceimpl Flags
impl Flags
Sourcepub fn matching(flags: &[u8]) -> impl Iterator<Item = Self> + '_
pub fn matching(flags: &[u8]) -> impl Iterator<Item = Self> + '_
Iterates over the flags that are present in the provided flags bytes.
Sourcepub fn short_name(&self) -> &'static str
pub fn short_name(&self) -> &'static str
An abbreviated form of the flag name.
See Flags::name for the full name.
Sourcepub fn name(&self) -> &'static str
pub fn name(&self) -> &'static str
The human-readable name of the flag.
See Flags::short_name for a shorter string for use if compactness is important.