pub enum ConversionError<T> {
Python(PyErr),
Native(T),
}Expand description
Represents the two major kinds of errors that can occur when converting between Rust and Python.
Variants
Python(PyErr)
Occurs across the Python/native boundary.
Native(T)
Occurs within the native ecosystem, such as when performing more transformations before finally converting to the native type.